-- globals
local game = LuaGame(Game)
local party = LuaParty(Party)
local townState = LuaTownState(TownState)
local dialog = LuaDialogManager(DialogManager)

--[[
	General
]]--

function isAvailable ()
	return true
end

function getSource ()
	return "general"
end

function getName ()
	return "Preparation Is Key"
end

function getDescription ()
	return
		"Greetings!\n\n"..
		"In order to go down in history as a famous pioneer you first need to do some things to get started.\n\n"..
		"Preparation is key, so before setting out into the wilderness it's time to do some shopping and get some basic equipment and tools.\n\n"..
		--"Remember that your party is everything, so gather up some men and equip them with tools and items they need.\n\n"..
		--"But even more importantly - build them a ship to sail.\n"..
		"Check out the Objectives page for list of things you need to accomplish."
end

--[[
	Functions related to objectives
]]--

local function numberOfExtraObjectives ()
	local ctx = LuaDialogContext(dialog:getContext("merchant2"))
	if ctx:getBoolean(0) == true then
		return 1
	end
	return 0
end

function getNumberOfObjectives ()
	return (2 + numberOfExtraObjectives())
end

function getObjectiveText(index)
	--[[if index == 1 then return "Build a Brig"
	elseif index == 2 then return "Increase party size to 2"
	elseif index == 3 then return "Get some basic equipment"
	elseif index == 4 then return "Stock up on food and water"]]--
	--if index == 1 then return "Increase party size to 2"
	
	local extraObjectives = numberOfExtraObjectives()
	
	if extraObjectives == 1 then
		if index == 1 then
			return "Travel to Marciudad"
		end
	end
	
	if index == (extraObjectives + 1) then 
		return "Get some basic equipment"
	elseif index == (extraObjectives + 2) then
		return "Stock up on food and water"
	end

	
	
	return ""
end

function getObjectiveHelpText(index)
	--[[if index == 1 then return "Go to the Harbour and start construction on the first Brig. Then visit the Tavern and advance the season."
	elseif index == 2 then return "Go the Tavern and create a new member for the party. When starting out, a soldier or a hunter would be great addition to the group."
	elseif index == 3 then return "These are the items you should currently purchase from the Supply store: a flask for each of the members, a tent, an axe, a sword or other melee weapon, a bow for hunting and flint for lighting campfires."
	elseif index == 4 then return "Get at least 80 units of fresh water and 100 units of dried meat (or other type of food)."]]--
	--if index == 1 then return "Go the Tavern and create a new member for the party. When starting out, a soldier or a hunter would be great addition to the group."
	
	local extraObjectives = numberOfExtraObjectives()
		
	if extraObjectives == 1 then
		if index == 1 then
			return "See if you can find a way to travel to Marciudad."
		end
	end
		
	if index == (extraObjectives + 1) then
		return "Check the local supply store for the following items: an axe, a flask, a tent and a flint for lighting campfires.\n\nWeapons are optional, depending on the skills of your character. If you have a melee skill, buy a sword or a bow if you have ranged weaponry skill."
	elseif index == (extraObjectives + 2) then
		return "Get at least 90 units of fresh water and 120 units of dried meat (or other type of food)."
	end
	
	return ""
end

function isObjectiveCompleted(index)

	-- Build a Brig
	if index == 99 then
		-- We have a ship
		if party:getVesselCount() > 0 then
			-- And it's not being built
			if LuaShip(party:getVessel(1)):checkStateFlag(Ship.Built) == false then
				return true
			end
		end
	end
		
	-- Increase party size to 2
	--[[
	elseif index == 1 then
		if party:getMemberCount() >= 2 then
			return true
		end
	]]--
	
	local extraObjectives = numberOfExtraObjectives()
	
	if extraObjectives == 1 then
		if index == 1 then
			if townState:getTownIndex() == 0 then
				return true
			end
		end
	end
	
	-- Get some basic equipment
	if index == (extraObjectives + 1) then
		local flaskCount = townState:countSupplyTypeTotal(Items.Flask)
		if (flaskCount >= party:getMemberCount() and flaskCount >= 1)
			-- At least one of each of the following items
			and townState:countSupplyTypeTotal(Items.Tent) > 0
			and townState:countSupplyTypeTotal(Items.Axe) > 0
			and townState:countSupplyTypeTotal(Items.Flint) > 0
			-- and (townState:countSupplyTypeTotal(Items.Bow) > 0 or townState:countSupplyTypeTotal(Items.Crossbow) > 0)
			-- and townState:countSupplyCategoryTotal(ItemCategory.MeleeWeapon) > 0
		then
			return true
		end
		
	-- Stock up on food and water
	elseif index == (extraObjectives + 2) then
		if townState:countSupplyCategoryTotal(ItemCategory.Food) >= 120 and townState:countSupplyTypeTotal(Items.Water) >= 90 then
			return true
		end
	end

	return false

end

--[[
	Functions related to rewards
]]--

function getNumberOfRewards ()
	return 0
end

function shouldAutoCollectRewards ()
	return true
end

function onComplete ()

end

function onAccepted ()

end