-- globals
local game = LuaGame(Game)
local party = LuaParty(Party)
local townState = LuaTownState(TownState)
local dialog = LuaDialogManager(DialogManager)
local quests = LuaQuests(Quests)

--[[
	General
]]--

function isAvailable ()
	local ctx = LuaDialogContext(dialog:getContext("tavernkeeper1"))
	return ctx:getBoolean(0)
end

function getSource ()
	return "general"
end

function getName ()
	return "Return To Safety"
end

function getDescription ()
	return
		"The town supply provisioner and shipwright were last seen sailing north around the penisula. They are presumed marooned somewhere, hopefully alive and well. They were possibly hit by the same storm that troubled you.\n\nFollow their last known path and keep your eyes open for any shipwrecks."
end

--[[
	Functions related to objectives
]]--

function getNumberOfObjectives ()
	return 3
end

function getObjectiveText(index)
	if index == 1 then 
		return "Locate the shipwreck"
	elseif index == 2 then
		return "Find the castaways"
	elseif index == 3 then
		return "Return to Reval"
	end
	
	return ""
end

function getObjectiveHelpText(index)

	if index == 1 then
		return "The two were last seen heading north around the penisula. This is where you should be headed. The game will let you know when you find it."
	elseif index == 2 then
		return "Get ashore and find where the castaways are camping."
	elseif index == 3 then
		return "Sail back to Reval to complete the quest."
	end
	
	return ""
end

function isObjectiveCompleted(index)
	local questContext = LuaDialogContext(dialog:getContext("recoveryquest"))
	if index == 1 and questContext:getBoolean(1) == true then
		return true
	elseif index == 2 and questContext:getBoolean(2) == true then
		return true
	elseif index == 3 and questContext:getBoolean(1) == true and questContext:getBoolean(2) == true and townState:getTownIndex() == 1 then
		return true
	end
	return false
end

--[[
	Functions related to rewards
]]--

function getNumberOfRewards ()
	return 1
end

function getRewardText(index)
	if game:getDifficulty() == 0 then
		return "+150 reputation"
	elseif game:getDifficulty() == 1 then
		return "+100 reputation"
	elseif game:getDifficulty() == 2 then
		return "+75 reputation"
	end
end

function shouldAutoCollectRewards ()
	return true
end

function onComplete ()

	local reputationReward = 150;
	
	if game:getDifficulty() == 1 then
		reputationReward = 100
	elseif game:getDifficulty() == 2 then
		reputationReward = 75
	end

	party:increaseReputation(reputationReward)
	
	local provisionerCtx = LuaDialogContext(dialog:getContext("provisioner"))
	
	provisionerCtx:setIsAvailable(true)
	
end

function onAccepted ()

end
