local game = LuaGame(Game)
local party = LuaParty(Party)
local quests = LuaQuests(Quests)
local dialog = LuaDialogManager(DialogManager)
local townState = LuaTownState(TownState)

--[[
	General
]]--

function isAvailable ()
	if quests:isQuestCompleted("gettingstarted") then
		return true
	else
		return false
	end
end

function getSource ()
	return "merchant"
end

function getName ()
	return "Spice Run"
end

function getDescription ()
	return
		"I am a humble merchant and I'm always looking for new goods to enrichen my stock.\n\n"..
		"I hear you are new in town and are looking to get into the exploration business. "..
		"Methinks you should start small and as it happens I have for you just the journey to undertake.\n\n"..
		"Go to the small island east of here known as Hios and gather for me some extraordinary spices. "..
		"Not many people dare to go the island because of the bears and wolves, so prepare to defend yourself."
end

--[[
	Functions related to objectives
]]--

function getNumberOfObjectives ()
	return 2
end

function getObjectiveText(index)

	if index == 2 then
		if game:getDifficulty() == 0 then
			return "Collect 25 units of spices from Hios"
		elseif game:getDifficulty() == 1 then
			return "Collect 40 units of spices from Hios"
		elseif game:getDifficulty() == 2 then
			return "Collect 60 units of spices from Hios"
		end
	elseif index == 1 then
		return "Find means of transportation"
	end
	
	return ""
end

function getObjectiveHelpText(index)

	if index == 2 then
		return "Spices can usually be found in more in-land areas."
	elseif index == 1 then
		return "Your best bet is to charter a vessel. Check the tavern to see if anyone knows of anything."
	end
	
	return ""
end


function isObjectiveCompleted(index)

	if index == 2 then
	
		local spiceToCollect = 25;
		if game:getDifficulty() == 1 then
			spiceToCollect = 40
		elseif game:getDifficulty() == 2 then
			spiceToCollect = 60
		end
		
		-- Have we enough spices?
		if party:countResource(Items.Herbs, Herbs.Spice) >= spiceToCollect then
			return true
		end
		
	elseif index == 1 then
	
		local barlowContext = LuaDialogContext(dialog:getContext("captainbarlow"))
	
		if barlowContext:getBoolean(1) == true then
			return true;
		end
	
	end
	
	return false
end

--[[
	Functions related to rewards
]]--

function getNumberOfRewards ()
	return 2
end

function getRewardText(index)

	if index == 1 then
		if game:getDifficulty() == 0 then
			return "1500 gold"
		elseif game:getDifficulty() == 1 then
			return "1000 gold"
		elseif game:getDifficulty() == 2 then
			return "500 gold"
		end
	elseif index == 2 then
		if game:getDifficulty() == 0 then
			return "+100 reputation"
		elseif game:getDifficulty() == 1 then
			return "+50 reputation"
		elseif game:getDifficulty() == 2 then
			return "+25 reputation"
		end
	end
end

function shouldAutoCollectRewards ()
	return false
end

function shouldShowRewardButton ()
	if townState:getTownIndex() == 0 then
		return true
	end
	return false
end

function onComplete ()

	local spiceToCollect = 25;
	local goldReward = 1500;
	local reputationReward = 100;
	
	if game:getDifficulty() == 1 then
		spiceToCollect = 40
		goldReward = 1000
		reputationReward = 50
	elseif game:getDifficulty() == 2 then
		spiceToCollect = 60
		goldReward = 500
		reputationReward = 25
	end
	
	party:removeResource(Items.Herbs, Herbs.Spice, spiceToCollect);
	party:increaseTreasure(goldReward)
	party:increaseReputation(reputationReward)
	
end

function onAccepted ()

end